@@ -17,7 +17,7 @@
 static YColorName dialogBg(&clrDialog);
 
 YDialog::YDialog():
-    YFrameClient(nullptr, nullptr),
+    YFrameClient(nullptr, nullptr, None),
     fGradient(dialogbackPixbuf),
     fSurface(dialogBg, dialogbackPixmap, getGradient())
 {
@@ -114,10 +114,9 @@ void YDialog::repaint() {
 }
 
 bool YDialog::handleKey(const XKeyEvent &key) {
-    if (key.type == KeyPress) {
+    if (key.type == KeyRelease) {
         KeySym k = keyCodeToKeySym(key.keycode);
         int m = KEY_MODMASK(key.state);
-
         if (k == XK_Escape && m == 0) {
             handleClose();
             return true;
